## ecr.commands.cmd_cls

src/ecr/commands/cmd_cls.py
    1
    2
    3
    4
    5
    6
    7
    8
    9
    10
    11
    12
    from .. import ui
    from ..ui.command import Command, Namespace, ReturnCode

    class ClsCommand(Command):
        @staticmethod
        def default(args: Namespace)->ReturnCode:  # pylint: disable=W0613
            ui.getConsole().clear()
            return ReturnCode.OK

        def __init__(self):
            super().__init__("cls", help="Clear console", func=ClsCommand.default)